@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # coding: utf-8
 
-# In[1]:
+# In[94]:
 
 
 try:
@@ -12,10 +12,10 @@ except:
         pass
 
 
-# In[94]:
+# In[95]:
 
 
-version = '0.52'
+version = '0.53'
 
 import re
 import tempfile
@@ -32,7 +32,7 @@ import stat
 
 # # Helper Functions
 
-# In[95]:
+# In[96]:
 
 
 def is_testing():
@@ -42,7 +42,7 @@ def is_testing():
         return False
 
 
-# In[96]:
+# In[97]:
 
 
 def isnotebook():
@@ -53,7 +53,7 @@ def isnotebook():
     return False
 
 
-# In[97]:
+# In[98]:
 
 
 def testPrint(*args):
@@ -63,7 +63,7 @@ def testPrint(*args):
 
 # # Requiremtns
 
-# In[98]:
+# In[99]:
 
 
 requirements = []
@@ -92,14 +92,14 @@ from IPython.core.display import display, HTML
 
 # # Lists
 
-# In[99]:
+# In[100]:
 
 
 def listsGetPairsFromTwoLists(list1, list2):
     return list(zip(list1, list2))
 
 
-# In[100]:
+# In[101]:
 
 
 if is_testing():
@@ -109,14 +109,14 @@ if is_testing():
     print(listsGetPairsFromTwoLists(listAbcd, list1234))
 
 
-# In[101]:
+# In[102]:
 
 
 def listSequentialOverlappingPairs(l):
     return list(zip(l[:-1], l[1:]))
 
 
-# In[102]:
+# In[103]:
 
 
 if is_testing():
@@ -132,7 +132,7 @@ if is_testing():
 
 # # List of Strings
 
-# In[103]:
+# In[104]:
 
 
 regex_cache = {}
@@ -142,35 +142,35 @@ def sListFilter(l, re_include=".*", re_exclude='^\b$'):
     return [e for e in l if regex_cache[re_include].search(e) and not regex_cache[re_exclude].search(e)]
 
 
-# In[104]:
+# In[105]:
 
 
 if is_testing():
     sListFilter(['good x', 'other good x', 'without the letter before y'])
 
 
-# In[105]:
+# In[106]:
 
 
 if is_testing():
     print(sListFilter(['good x', 'other good x', 'without the letter before y'], re_include='x'))
 
 
-# In[106]:
+# In[107]:
 
 
 if is_testing():
     print(sListFilter(['not enough x', 'enough xx', 'enough xx and also z'], re_include='xx+'))
 
 
-# In[107]:
+# In[108]:
 
 
 if is_testing():
     print(sListFilter(['not enough x', 'enough xx', 'enough xx and also z'], re_include='xx+', re_exclude='z'))
 
 
-# In[108]:
+# In[109]:
 
 
 def lCsv(l, force_oneline=False):
@@ -186,21 +186,21 @@ def lCsv(l, force_oneline=False):
     return ", ".join([str(e) for e in l])
 
 
-# In[109]:
+# In[110]:
 
 
 if is_testing():
     print(lCsv(['a', 'b', 1, 3.14]))
 
 
-# In[110]:
+# In[111]:
 
 
 if is_testing():
     print(lCsv([['a', 'b'], 1, 3.14]))
 
 
-# In[111]:
+# In[112]:
 
 
 if is_testing():
@@ -209,14 +209,14 @@ if is_testing():
 
 # # Text files
 
-# In[184]:
+# In[113]:
 
 
 def txtread(path):
     if 'http://' in path or 'https://' in path:
         return urlopen(path).read().decode()
     elif 'gs://' in path:
-        gsTxtread(path)
+        return gsTxtread(path)
     else:
         with open(path, 'r') as f:
             return f.read()
@@ -230,7 +230,7 @@ def txtwrite(path, txt):
             return f.write(txt)
 
 
-# In[113]:
+# In[114]:
 
 
 if is_testing():
@@ -239,7 +239,7 @@ if is_testing():
 
 # # List of Strings
 
-# In[114]:
+# In[115]:
 
 
 regex_cache = {}
@@ -251,35 +251,35 @@ def sListFilter(listOfStrings, re_include=".*", re_exclude='^\b$'):
 
 # ### Examples
 
-# In[115]:
+# In[116]:
 
 
 if is_testing():
     print(sListFilter(['good x', 'other good x', 'without the letter before y']))
 
 
-# In[116]:
+# In[117]:
 
 
 if is_testing():
     print(sListFilter(['good x', 'other good x', 'without the letter before y'], re_include='x'))
 
 
-# In[117]:
+# In[118]:
 
 
 if is_testing():
     print(sListFilter(['not enough x', 'enough xx', 'enough xx and also z'], re_include='xx+'))
 
 
-# In[118]:
+# In[119]:
 
 
 if is_testing():
     print(sListFilter(['not enough x', 'enough xx', 'enough xx and also z'], re_include='xx+', re_exclude='z'))
 
 
-# In[119]:
+# In[120]:
 
 
 if is_testing():
@@ -288,7 +288,7 @@ if is_testing():
 
 # # GCP Google Cloud Platform
 
-# In[120]:
+# In[121]:
 
 
 import warnings
@@ -312,7 +312,7 @@ def _gsBlob(path):
     return blob
 
 
-# In[121]:
+# In[122]:
 
 
 def gsGsToHttp(path):
@@ -322,7 +322,7 @@ def gsHttpToGs(path):
     return path.replace("https://storage.cloud.google.com/", "gs://").split("?")[0] # "?" is for possible "?authuser=0"
 
 
-# In[122]:
+# In[123]:
 
 
 def gsLs(path):
@@ -332,7 +332,7 @@ def gsLs(path):
     return ['gs://' + bucket + '/' + blob.name for blob in client.list_blobs(prefix=prefix)]
 
 
-# In[123]:
+# In[124]:
 
 
 def gsUploadFile(gsPath, path):
@@ -340,7 +340,7 @@ def gsUploadFile(gsPath, path):
     blob.upload_from_filename(path)
 
 
-# In[124]:
+# In[125]:
 
 
 def gsTxtread(path):
@@ -352,7 +352,7 @@ def gsTxtread(path):
     return blob.download_as_string().decode()
 
 
-# In[182]:
+# In[126]:
 
 
 def gsTxtwrite(path, s):
@@ -360,7 +360,7 @@ def gsTxtwrite(path, s):
     return blob.upload_from_string(s)
 
 
-# In[125]:
+# In[127]:
 
 
 def gsImwrite(path, img):
@@ -369,7 +369,7 @@ def gsImwrite(path, img):
     blob.upload_from_string(encimg.tobytes())
 
 
-# In[126]:
+# In[128]:
 
 
 def gsImread(path):
@@ -380,7 +380,7 @@ def gsImread(path):
 
 # # Images
 
-# In[127]:
+# In[129]:
 
 
 def imread(path):
@@ -414,7 +414,7 @@ def impad(img, top=0, bottom=0, left=0, right=0, color=255):
     return np.pad(img, [(top, bottom), (left, right), (0, 0)], 'constant', constant_values=color)
 
 
-# In[128]:
+# In[130]:
 
 
 def imshow(array, scale=1):
@@ -429,7 +429,7 @@ def imshow(array, scale=1):
         cv2.waitKey()
 
 
-# In[129]:
+# In[131]:
 
 
 if is_testing():
@@ -437,14 +437,14 @@ if is_testing():
     imshow(img)
 
 
-# In[130]:
+# In[ ]:
 
 
 if is_testing():
     imshow('http://via.placeholder.com/70.png')
 
 
-# In[131]:
+# In[ ]:
 
 
 def imscaleNN(img, s):
@@ -454,7 +454,7 @@ def imscaleBic(img, s):
     return cv2.resize(img, None, fx=s, fy=s, interpolation=cv2.INTER_CUBIC)
 
 
-# In[132]:
+# In[ ]:
 
 
 if is_testing():
@@ -473,7 +473,7 @@ if is_testing():
         imshow(out_large_interbic)
 
 
-# In[133]:
+# In[ ]:
 
 
 def imRepeat(img, height, width):
@@ -487,7 +487,7 @@ def imRepeat(img, height, width):
     return img
 
 
-# In[134]:
+# In[ ]:
 
 
 if is_testing():
@@ -495,33 +495,33 @@ if is_testing():
     imshow(imRepeat(img_random_color_3x5, 7, 11), scale=10)
 
 
-# In[135]:
+# In[ ]:
 
 
 def imNewWhite(height, width):
     return np.ones((height, width, 3)).astype(np.uint8) * 255
 
 
-# In[136]:
+# In[ ]:
 
 
 if is_testing(): imshow(imNewWhite(10, 500) - 30)
 
 
-# In[137]:
+# In[ ]:
 
 
 def imNewBlack(height, width):
     return np.zeros((height, width, 3)).astype(np.uint8)
 
 
-# In[138]:
+# In[ ]:
 
 
 if is_testing(): imshow(imNewBlack(10, 500))
 
 
-# In[139]:
+# In[ ]:
 
 
 def imAddNoiseGauss(img, std):
@@ -533,7 +533,7 @@ def imAddNoiseGauss(img, std):
 if is_testing(): imshow(imAddNoiseGauss(imread('http://via.placeholder.com/150.png'), 10))
 
 
-# In[140]:
+# In[ ]:
 
 
 def imJpgDegradation(img, quality):
@@ -546,7 +546,7 @@ def imJpgDegradation(img, quality):
 if is_testing(): imshow(imJpgDegradation(imread('http://via.placeholder.com/150.png'), 15))
 
 
-# In[141]:
+# In[ ]:
 
 
 def imCropCenter(img, size):
@@ -561,35 +561,35 @@ def imCropCenter(img, size):
     return img[h_start:h_end, w_start:w_end]
 
 
-# In[142]:
+# In[ ]:
 
 
 if is_testing(): 
     imshow(imCropCenter(imread('http://via.placeholder.com/40.png'), 10))
 
 
-# In[143]:
+# In[ ]:
 
 
 if is_testing(): 
     imshow(imCropCenter(imread('http://via.placeholder.com/40.png'), 49))
 
 
-# In[144]:
+# In[ ]:
 
 
 if is_testing(): 
     imshow(imCropCenter(imread('http://via.placeholder.com/40.png'), 50))
 
 
-# In[145]:
+# In[ ]:
 
 
 if is_testing(): 
     imshow(imCropCenter(imread('http://via.placeholder.com/40.png'), 100))
 
 
-# In[146]:
+# In[ ]:
 
 
 def imGallery(imgs, pad=0):
@@ -620,7 +620,7 @@ def imGallery(imgs, pad=0):
     return out
 
 
-# In[147]:
+# In[ ]:
 
 
 if is_testing():
@@ -628,49 +628,49 @@ if is_testing():
     listOfDummyImagesBlackToWhite = [imNewBlack(10, 10) + 25 * i for i in range(10)]
 
 
-# In[148]:
+# In[ ]:
 
 
 if is_testing():
     imshow(imGallery(listOfDummyImagesBlackToWhite[:1]))
 
 
-# In[149]:
+# In[ ]:
 
 
 if is_testing():
     imshow(imGallery(listOfDummyImagesBlackToWhite[:2]))
 
 
-# In[150]:
+# In[ ]:
 
 
 if is_testing():
     imshow(imGallery(listOfDummyImagesBlackToWhite[:2], pad=1))
 
 
-# In[151]:
+# In[ ]:
 
 
 if is_testing():
     imshow(imGallery(listOfDummyImagesBlackToWhite[:5], pad=1))
 
 
-# In[152]:
+# In[ ]:
 
 
 if is_testing():
     imshow(imGallery(listOfDummyImagesBlackToWhite[:9], pad=1))
 
 
-# In[153]:
+# In[ ]:
 
 
 if is_testing():
     imshow(imGallery(listOfDummyImagesBlackToWhite[:10], pad=1))
 
 
-# In[154]:
+# In[ ]:
 
 
 if is_testing():
@@ -680,14 +680,14 @@ if is_testing():
 
 # # Files
 
-# In[155]:
+# In[ ]:
 
 
 def fiFindByWildcard(wildcard):
     return natsort.natsorted(glob.glob(wildcard, recursive=True))
 
 
-# In[156]:
+# In[ ]:
 
 
 if is_testing():
@@ -716,7 +716,7 @@ if is_testing():
         imshow(imGallery(imgs))
 
 
-# In[157]:
+# In[ ]:
 
 
 def fiRemove(path):
@@ -744,7 +744,7 @@ def fiAgeHours(path):
     return (time.time() - os.stat(path)[stat.ST_MTIME]) / 3600
 
 
-# In[158]:
+# In[ ]:
 
 
 if is_testing():
@@ -778,7 +778,7 @@ if is_testing():
 
 # # Jupyter
 
-# In[159]:
+# In[ ]:
 
 
 def jnNbFullWidth():
@@ -792,7 +792,7 @@ def jnPandasSettings():
     pd.set_option('display.max_colwidth', None)
 
 
-# In[160]:
+# In[ ]:
 
 
 def jnImageRenderingPixelated():
@@ -804,7 +804,7 @@ def jnImageRenderingAuto():
     display(HTML('<style type = text/css> img { image-rendering: auto; } </style>'))
 
 
-# In[161]:
+# In[ ]:
 
 
 def jnDefault():
@@ -816,7 +816,7 @@ if is_testing():
     jnDefault()
 
 
-# In[162]:
+# In[ ]:
 
 
 def jnHtmlRow(strList, width=100):
@@ -829,7 +829,7 @@ if is_testing():
     
 
 
-# In[163]:
+# In[ ]:
 
 
 def jnImgToHtmlB64(img):
@@ -853,7 +853,7 @@ def jnImageRow(imgs, names=None, width=100):
     display(HTML(html))
 
 
-# In[164]:
+# In[ ]:
 
 
 if is_testing():
@@ -861,7 +861,7 @@ if is_testing():
    
 
 
-# In[165]:
+# In[ ]:
 
 
 
@@ -871,7 +871,7 @@ if is_testing():
 
 # # Shell
 
-# In[166]:
+# In[ ]:
 
 
 def shell(cmd):
@@ -886,7 +886,7 @@ def shell(cmd):
 
 # # GIT
 
-# In[167]:
+# In[ ]:
 
 
 def gitGetHash():
@@ -896,7 +896,7 @@ if is_testing():
     print(gitGetHash())
 
 
-# In[168]:
+# In[ ]:
 
 
 def gitGetBranch():
@@ -906,7 +906,7 @@ if is_testing():
     print(gitGetBranch())
 
 
-# In[169]:
+# In[ ]:
 
 
 def gitGetMessage():
@@ -916,7 +916,7 @@ if is_testing():
     print(gitGetMessage())
 
 
-# In[170]:
+# In[ ]:
 
 
 def gitGetAllFiles():
@@ -926,7 +926,7 @@ if is_testing():
     print(gitGetAllFiles())
 
 
-# In[171]:
+# In[ ]:
 
 
 def gitListByTime(path=None):
@@ -942,7 +942,7 @@ if is_testing():
     print(gitListByTime()[-3:])
 
 
-# In[172]:
+# In[ ]:
 
 
 def shellSortDirsBySize():
@@ -954,14 +954,14 @@ if is_testing():
 
 # # Package Files
 
-# In[173]:
+# In[ ]:
 
 
 if is_testing():
     package_files = {}
 
 
-# In[174]:
+# In[ ]:
 
 
 def shell(cmd):
@@ -969,7 +969,7 @@ def shell(cmd):
     return result.stdout.decode()
 
 
-# In[175]:
+# In[ ]:
 
 
 if is_testing():
@@ -1001,7 +1001,7 @@ setup(
 )""".format(requirements=", ".join(["'" + r + "'" for r in requirements]), version=version)
 
 
-# In[176]:
+# In[ ]:
 
 
 if is_testing():
@@ -1011,7 +1011,7 @@ description-file = README.md
 """
 
 
-# In[177]:
+# In[ ]:
 
 
 if is_testing():
@@ -1034,14 +1034,14 @@ OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 SOFTWARE."""
 
 
-# In[178]:
+# In[ ]:
 
 
 if is_testing():
     package_files['README.md'] = ""
 
 
-# In[179]:
+# In[ ]:
 
 
 if is_testing():
@@ -1050,7 +1050,7 @@ if is_testing():
     
 
 
-# In[180]:
+# In[ ]:
 
 
 if is_testing():
@@ -1061,7 +1061,7 @@ lx/__init__.py
 """
 
 
-# In[181]:
+# In[ ]:
 
 
 if is_testing():
